==> pdf-model-arlington-1.25.14-sources.jar: org/verapdf/model/alayer/ATarget.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface ATarget extends AObject {
	


	/**
	*/
	public Boolean getcontainsA();

	/**
	*/
	public Boolean getAHasTypeInteger();

	/**
	*/
	public Boolean getAHasTypeStringText();

	/**
	*/
	public Long getAIntegerValue();

	/**
	*/
	public String getAStringTextValue();

	/**
	*/
	public Boolean getcontainsN();

	/**
	*/
	public Boolean getNHasTypeStringByte();

	/**
	*/
	public Boolean getNEntryIsIndexInNameTreetrailerCatalogNamesEmbeddedFiles();

	/**
	*/
	public Boolean getcontainsP();

	/**
	*/
	public Boolean getPHasTypeInteger();

	/**
	*/
	public Boolean getPHasTypeStringByte();

	/**
	*/
	public Long getPIntegerValue();

	/**
	*/
	public Boolean getPEntryIsIndexInNameTreetrailerCatalogNamesDests();

	/**
	*/
	public Boolean getcontainsR();

	/**
	*/
	public Boolean getRHasTypeName();

	/**
	*/
	public String getRNameValue();

	/**
	*/
	public Boolean getcontainsT();

	/**
	*/
	public Boolean getTHasTypeDictionary();

	/**
	*/
	public Long getpagePAnnotsArraySize();

	/**
	*/
	public Boolean getpagePAnnotsHasTypeArray();
}

==> pdf-model-arlington-1.25.55-sources.jar: org/verapdf/model/alayer/ATarget.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface ATarget extends AObject {
	


	/**
	*/
	public Boolean getcontainsA();

	/**
	*/
	public String getAType();

	/**
	*/
	public Boolean getAHasTypeInteger();

	/**
	*/
	public Boolean getAHasTypeStringText();

	/**
	*/
	public Long getAIntegerValue();

	/**
	*/
	public String getAStringTextValue();

	/**
	*/
	public Boolean getcontainsN();

	/**
	*/
	public String getNType();

	/**
	*/
	public Boolean getNHasTypeStringByte();

	/**
	*/
	public Boolean getNEntryIsIndexInNameTreetrailerCatalogNamesEmbeddedFiles();

	/**
	*/
	public Boolean getcontainsP();

	/**
	*/
	public String getPType();

	/**
	*/
	public Boolean getPHasTypeInteger();

	/**
	*/
	public Boolean getPHasTypeStringByte();

	/**
	*/
	public Long getPIntegerValue();

	/**
	*/
	public Boolean getPEntryIsIndexInNameTreetrailerCatalogNamesDests();

	/**
	*/
	public Boolean getcontainsR();

	/**
	*/
	public String getRType();

	/**
	*/
	public Boolean getRHasTypeName();

	/**
	*/
	public String getRNameValue();

	/**
	*/
	public Boolean getcontainsT();

	/**
	*/
	public String getTType();

	/**
	*/
	public Boolean getTHasTypeDictionary();

	/**
	*/
	public Long getpagePAnnotsArraySize();

	/**
	*/
	public Boolean getpagePAnnotsHasTypeArray();
}
